@@ -290,7 +290,7 @@ class SFREAD:
 # LongLong in [ns] and no zero at TS06
             if otyp == 8 and dfmt == 13: # RMC:TIME-AD0, SXS:Time
                 logger.debug('Before getts06 dfmt:%d addr:%d len:%d data1:%d, %d', dfmt, addr, bytlen, data[0], data[1])
-                dout = 1e-9*(data - self.getts06(obj))
+                data = 1e-9*(data - self.getts06(obj))
                 logger.debug('%d',  self.getts06(obj))
 
             dout = sfobj.SFOBJ(data, sfho=sfo) # Add metadata
@@ -482,7 +482,7 @@ class SFREAD:
         """
 
         for lbl, sfo in self.sfh.items():
-            if sf.objid == jobj:
+            if sfo.objid == jobj:
                 return lbl
 
 
