@@ -333,7 +333,7 @@ class WW:
             if getError(error):
                 raise Exception('ww.shotfile.SetAreabase: Error writing areabase %s' %areaname)
             else:
-                logger.info('Written Areabase %s, sizes %d %d %d', areaname, sizes[:3])
+                logger.info('Written Areabase %s, sizes %d %d %d', areaname, sizes[0], sizes[1], sizes[2])
 
 
     def SetParameter(self, set_name, par_name, data):
